reuse.i18n module - reuse 6.1.2 documentation

Skip to content
Back to top
View this page

# reuse.i18n module

`gettext` plumbing of `reuse`.

reuse.i18n.TRANSLATIONS: NullTranslations = <gettext.GNUTranslations object>

  Translations object used throughout `reuse`. The translations are sourced from `reuse/locale/<lang>/LC_MESSAGES/reuse.mo`.

reuse.i18n.gettext(message)

  `gettext.NullTranslations.gettext()` of `TRANSLATIONS`

reuse.i18n.ngettext(msgid1, msgid2, n)

  `gettext.NullTranslations.ngettext()` of `TRANSLATIONS`

reuse.i18n.pgettext(context, message)

  `gettext.NullTranslations.pgettext()` of `TRANSLATIONS`

reuse.i18n.npgettext(context, msgid1, msgid2, n)

  `gettext.NullTranslations.npgettext()` of `TRANSLATIONS`